@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::PERLANCAR::SortSections;
 
-our $DATE = '2016-01-19'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-10-07'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -54,7 +54,8 @@ sub finalize_document {
             'ENVIRONMENT',
             'FILES',
 
-            # links/pointers
+            # links/pointers/extra information
+            'HISTORY',
             'HOMEPAGE',
             'SOURCE',
             'BUGS',
@@ -83,7 +84,7 @@ Pod::Weaver::Plugin::PERLANCAR::SortSections - Sort POD sections like PERLANCAR
 
 =head1 VERSION
 
-This document describes version 0.02 of Pod::Weaver::Plugin::PERLANCAR::SortSections (from Perl distribution Pod-Weaver-Plugin-PERLANCAR-SortSections), released on 2016-01-19.
+This document describes version 0.03 of Pod::Weaver::Plugin::PERLANCAR::SortSections (from Perl distribution Pod-Weaver-Plugin-PERLANCAR-SortSections), released on 2016-10-07.
 
 =head1 SYNOPSIS
 
